@@ -63,7 +63,7 @@ public:
 		dat = new T*[(size_t)1<<MGL_PB];
 		*dat = new T[(size_t)1<<MGL_PB];	reserve(st.n);
 		for(size_t i=0;i<nb;i++)
-			memcpy(dat[i],st.dat[i],((size_t)1<<MGL_PB)*sizeof(T));
+			memcpy((void*)(dat[i]),st.dat[i],((size_t)1<<MGL_PB)*sizeof(T));
 		n=st.n;	}
 	mglStack()
 	{	mutex = 0;	n=0;	nb=1;	MGL_PB = mgl_bsize(0);
@@ -109,7 +109,7 @@ public:
 	{
 		clear();	reserve(st.n);
 		for(size_t i=0;i<nb;i++)
-			memcpy(dat[i],st.dat[i],((size_t)1<<MGL_PB)*sizeof(T));
+			memcpy((void*)(dat[i]),st.dat[i],((size_t)1<<MGL_PB)*sizeof(T));
 		n = st.n;	return st;
 	}
 };
@@ -117,16 +117,24 @@ public:
 /// Structure for transformation matrix
 struct MGL_EXPORT mglMatrix
 {
-	float x,y,z,pf;
-	float b[9];
+	float x,y,z,pf;	// shifting values
+	float b[9];		// matrix coefficients
+	float ib[9];	// inverse matrix coefficients
 	bool norot;	// flag to disable pnts rotation
 	mglMatrix()	{	clear();	}
-	mglMatrix(const mglMatrix &aa) : x(aa.x),y(aa.y),z(aa.z),pf(aa.pf),norot(aa.norot) 	{	memcpy(b,aa.b,9*sizeof(float));	}
+	mglMatrix(const mglMatrix &aa) : x(aa.x),y(aa.y),z(aa.z),pf(aa.pf),norot(aa.norot)
+	{	memcpy(b,aa.b,9*sizeof(float));	memcpy(ib,aa.ib,9*sizeof(float));	}
 	void Rotate(mreal tetz,mreal tetx,mreal tety);
 	void RotateN(mreal Tet,mreal x,mreal y,mreal z);
-	inline void clear()	{	x=y=z=pf=0;	memset(b,0,9*sizeof(float));	b[0]=b[4]=b[8]=1;	norot=false;	}
+	inline void clear()
+	{	x=y=z=pf=0;	memset(b,0,9*sizeof(float));	memset(ib,0,9*sizeof(float));	b[0]=b[4]=b[8]=ib[0]=ib[4]=ib[8]=1;	norot=false;	}
 	inline const mglMatrix &operator=(const mglMatrix &a)
-	{	x=a.x;	y=a.y;	z=a.z;	pf=a.pf;	memcpy(b,a.b,9*sizeof(float));	norot=false;	return a;	}
+	{	x=a.x;	y=a.y;	z=a.z;	pf=a.pf;	memcpy(b,a.b,9*sizeof(float));	memcpy(ib,a.ib,9*sizeof(float));	norot=false;	return a;	}
+	inline void invert()
+	{	float d = b[0]*(b[4]*b[8]-b[5]*b[7])-b[1]*(b[3]*b[8]-b[5]*b[6])+b[2]*(b[3]*b[7]-b[4]*b[6]);	// determinant
+		ib[0] = (b[4]*b[8]-b[5]*b[7])/d;	ib[1] = (b[2]*b[7]-b[1]*b[8])/d;	ib[2] = (b[1]*b[5]-b[2]*b[4])/d;
+		ib[3] = (b[5]*b[6]-b[3]*b[8])/d;	ib[4] = (b[0]*b[8]-b[2]*b[6])/d;	ib[5] = (b[2]*b[3]-b[0]*b[5])/d;
+		ib[6] = (b[3]*b[7]-b[4]*b[6])/d;	ib[7] = (b[1]*b[6]-b[0]*b[7])/d;	ib[8] = (b[0]*b[4]-b[1]*b[3])/d;	}
 };
 inline bool operator==(const mglMatrix &a, const mglMatrix &b)
 {	return ((a.x-b.x)*(a.x-b.x)+(a.y-b.y)*(a.y-b.y)+(a.z-b.z)*(a.z-b.z)+(a.pf-b.pf)*(a.pf-b.pf)==0)&&!memcmp(b.b,a.b,9*sizeof(float));}
@@ -158,6 +166,9 @@ struct MGL_EXPORT mglPrim	// NOTE: use float for reducing memory size
 	mglPrim(const mglPrim &aa) : n1(aa.n1),n2(aa.n2),n3(aa.n3),n4(aa.n4),type(aa.type),angl(aa.angl),id(aa.id),z(aa.z),w(aa.w),m(aa.m) 	{}
 	const mglPrim &operator=(const mglPrim &aa)
 	{	n1=aa.n1;	n2=aa.n2;	n3=aa.n3;	n4=aa.n4;	type=aa.type;	angl=aa.angl;	id=aa.id;	z=aa.z;	w=aa.w;	m=aa.m;	return aa;	}
+#if MGL_HAVE_RVAL
+	mglPrim(mglPrim &&aa) : n1(aa.n1),n2(aa.n2),n3(aa.n3),n4(aa.n4),type(aa.type),angl(aa.angl),id(aa.id),z(aa.z),w(aa.w),m(aa.m) 	{}
+#endif
 };
 bool operator<(const mglPrim &a,const mglPrim &b);
 bool operator>(const mglPrim &a,const mglPrim &b);
@@ -192,7 +203,7 @@ struct MGL_EXPORT mglBlock
 	int id;		///< object id
 
 	mglBlock():n1(0),n2(0),n3(0),n4(0),AmbBr(0.5),DifBr(0.5),id(0)	{}
-	mglBlock(const mglBlock &aa)	{	memcpy(this, &aa, sizeof(mglBlock));	}
+	mglBlock(const mglBlock &aa)	{	memcpy((void*)this, &aa, sizeof(mglBlock));	}
 	const mglBlock &operator=(const mglBlock &aa)
 	{	n1=aa.n1;	n2=aa.n2;	n3=aa.n3;	n4=aa.n4;	for(int i=0;i<10;i++)	light[i]=aa.light[i];
 		AmbBr=aa.AmbBr;	DifBr=aa.DifBr;	B=aa.B;	id=aa.id;	return aa;	}
@@ -242,6 +253,9 @@ struct MGL_EXPORT mglPnt	// NOTE: use float for reducing memory size
 	mglPnt(const mglPnt &aa) : sub(aa.sub)	{	memcpy(dat,aa.dat,15*sizeof(float));	}
 	inline const mglPnt&operator=(const mglPnt &aa)	{ sub=aa.sub;	memcpy(dat,aa.dat,15*sizeof(float));	return aa;	}
 	inline bool same(const mglPnt &p, mreal d)	const {	return fabs(x-p.x)<d && fabs(y-p.y)<d;	}
+#if MGL_HAVE_RVAL
+	mglPnt(mglPnt &&d):x(d.x),y(d.y),z(d.z),u(d.u),v(d.v),w(d.w),r(d.r),g(d.g),b(d.b),a(d.a),xx(d.xx),yy(d.yy),zz(d.zz),c(d.c),ta(d.ta),sub(d.sub)	{}
+#endif
 };
 inline mglPnt operator+(const mglPnt &a, const mglPnt &b)
 //{	mglPnt p;	for(long i=0;i<10;i++)	p.dat[i] = a.dat[i]+b.dat[i];	p.sub=a.sub;	return p;	}
@@ -298,8 +312,8 @@ struct MGL_EXPORT mglTexture
 	{	col = new mglColor[MGL_TEXTURE_COLOURS];	Set(cols,smooth,alpha);	}
 	mglTexture(const mglTexture &aa) : n(aa.n),Smooth(aa.Smooth),Alpha(aa.Alpha)
 	{	col = new mglColor[MGL_TEXTURE_COLOURS];	memcpy(Sch,aa.Sch,260);
-		memcpy(col,aa.col,MGL_TEXTURE_COLOURS*sizeof(mglColor));
-		c0 = new mglColor[2*aa.n];	memcpy(c0,aa.c0,2*aa.n*sizeof(mglColor));
+		memcpy((void*)col,aa.col,MGL_TEXTURE_COLOURS*sizeof(mglColor));
+		c0 = new mglColor[2*aa.n];	memcpy((void*)c0,aa.c0,2*aa.n*sizeof(mglColor));
 		val = new float[aa.n];		memcpy(val,aa.val,aa.n*sizeof(float));	}
 #if MGL_HAVE_RVAL
 	mglTexture(mglTexture &&aa) : n(aa.n),c0(aa.c0),val(aa.val),Smooth(aa.Smooth),Alpha(aa.Alpha)
@@ -320,7 +334,7 @@ struct MGL_EXPORT mglTexture
 	void GetRGBAOBJ(unsigned char *f) const;	// Export repeating border colors, since OBJ by default wraps textures and we need an extra boundary to work around implementation quirks
 	inline const mglTexture &operator=(const mglTexture &aa)
 	{	n=aa.n;	Smooth=aa.Smooth;	Alpha=aa.Alpha;
-		memcpy(col,aa.col,MGL_TEXTURE_COLOURS*sizeof(mglColor));
+		memcpy((void*)col,aa.col,MGL_TEXTURE_COLOURS*sizeof(mglColor));
 		memcpy(Sch,aa.Sch,260);	return aa;	}
 };
 //-----------------------------------------------------------------------------
