@@ -3,7 +3,7 @@
  * Copyright (C) 2007-2016 Alexey Balakin <mathgl.abalakin@gmail.ru>       *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU Library General Public License as       *
+ *   it under the terms of the GNU Lesser General Public License  as       *
  *   published by the Free Software Foundation; either version 3 of the    *
  *   License, or (at your option) any later version.                       *
  *                                                                         *
@@ -12,7 +12,7 @@
  *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
  *   GNU General Public License for more details.                          *
  *                                                                         *
- *   You should have received a copy of the GNU Library General Public     *
+ *   You should have received a copy of the GNU Lesser General Public     *
  *   License along with this program; if not, write to the                 *
  *   Free Software Foundation, Inc.,                                       *
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
@@ -183,6 +183,8 @@ uintptr_t MGL_EXPORT mgl_datac_section_(uintptr_t *d, uintptr_t *ids, const char
 /** If section id is negative then reverse order is used (i.e. -1 give last section). */
 HADT MGL_EXPORT mgl_datac_section_val(HCDT dat, long id, char dir, mreal val);
 uintptr_t MGL_EXPORT mgl_datac_section_val_(uintptr_t *d, int *id, const char *dir, mreal *val,int);
+/// Evaluate formula 'str' for given list of variables.
+HADT MGL_EXPORT mgl_formula_calc_c(const char *str, long n, ...);
 
 /// Equidistantly fill the data to range [x1,x2] in direction dir
 void MGL_EXPORT mgl_datac_fill(HADT dat, mdual x1,mdual x2,char dir);
@@ -213,10 +215,15 @@ void MGL_EXPORT mgl_datac_modify_(uintptr_t *dat, const char *eq,int *dim,int);
 void MGL_EXPORT mgl_datac_modify_vw(HADT dat, const char *eq,HCDT vdat,HCDT wdat);
 void MGL_EXPORT mgl_datac_modify_vw_(uintptr_t *dat, const char *eq, uintptr_t *vdat, uintptr_t *wdat,int);
 
-/// Limit the data to be inside [-v,v], keeping the original sign
+/// Limit the data to be inside [-v,v], keeping the original phase
 void MGL_EXPORT mgl_datac_limit(HADT dat, mreal v);
 void MGL_EXPORT mgl_datac_limit_(uintptr_t *dat, mreal *v);
 
+/// Keep the data phase/value along line i and j in given direction. 
+/** Parameter "how" may contain: 'x','y' or 'z' for direction (default is 'y'); 'a' for keeping amplitude instead of phase.*/
+void MGL_EXPORT mgl_datac_keep(HADT dat, const char *how, long i, long j);
+void MGL_EXPORT mgl_datac_keep_(uintptr_t *d, const char *how, long *i, long *j, int);
+
 /// Put value to data element(s)
 void MGL_EXPORT mgl_datac_put_val(HADT dat, mdual val, long i, long j, long k);
 void MGL_EXPORT mgl_datac_put_val_(uintptr_t *dat, mdual *val, int *i, int *j, int *k);
@@ -321,6 +328,9 @@ void MGL_EXPORT mgl_datac_fft_(uintptr_t *dat, const char *dir,int);
 HADT MGL_EXPORT mgl_datac_correl(HCDT dat1, HCDT dat2, const char *dir);
 uintptr_t MGL_EXPORT mgl_datac_correl_(uintptr_t *dat1, uintptr_t *dat2, const char *dir,int);
 /// Calculate one step of diffraction by finite-difference method with parameter q
+/** Parameter \a how may contain:
+ * ‘x‘,‘y‘,‘z‘ or ‘r‘  for directions or axial along x,
+ * ‘e‘,‘g‘,‘0‘,‘1‘,‘2‘,‘3‘ for boundary conditions: exp, Gaussian, zero, constant, linear, quadratic.*/
 void MGL_EXPORT mgl_datac_diffr(HADT dat, const char *how, mreal q);
 void MGL_EXPORT mgl_datac_diffr_(uintptr_t *d, const char *how, double q,int l);
 /// Apply wavelet transform
