@@ -66,7 +66,10 @@
 #else
 #define MGL_FUNC_CONST
 #define MGL_FUNC_PURE
+#define MGL_FUNC_INIT
+#define MGL_FUNC_FINI
 #endif
+
 #define MGL_EXPORT_CONST	MGL_EXPORT MGL_FUNC_CONST
 #define MGL_EXPORT_PURE		MGL_EXPORT MGL_FUNC_PURE
 #define MGL_LOCAL_CONST		MGL_NO_EXPORT MGL_FUNC_CONST
@@ -138,7 +141,9 @@ typedef long msize;
 #define getcwd	_getcwd
 #define chdir	_chdir // BORLAND has chdir
 #endif
+#if (_MSC_VER<1500)
 #define snprintf _snprintf
+#endif
 #if (_MSC_VER<1600) // based on https://hg.python.org/cpython/rev/9aedb876c2d7
 #define hypot	_hypot
 #endif
@@ -288,6 +293,7 @@ extern MGL_EXPORT uint64_t mgl_mask_val[16];
 #define MGL_GRAY_MODE 		0x00200000 	///< Convert all colors to gray ones
 #define MGL_FULL_CURV 		0x00400000 	///< Disable omitting points in straight-line part(s).
 #define MGL_NO_SCALE_REL 	0x00800000 	///< Disable font scaling in relative inplots
+#define MGL_FAST_PRIM		0x01000000	///< Disable accurate primitive cutting at axis borders
 //-----------------------------------------------------------------------------
 #ifdef __cplusplus
 #include <string>
