@@ -3,7 +3,7 @@
  * Copyright (C) 2007-2016 Alexey Balakin <mathgl.abalakin@gmail.ru>       *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU Library General Public License as       *
+ *   it under the terms of the GNU Lesser General Public License  as       *
  *   published by the Free Software Foundation; either version 3 of the    *
  *   License, or (at your option) any later version.                       *
  *                                                                         *
@@ -12,7 +12,7 @@
  *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
  *   GNU General Public License for more details.                          *
  *                                                                         *
- *   You should have received a copy of the GNU Library General Public     *
+ *   You should have received a copy of the GNU Lesser General Public     *
  *   License along with this program; if not, write to the                 *
  *   Free Software Foundation, Inc.,                                       *
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
@@ -67,7 +67,8 @@ class MGL_EXPORT mglFont
 {
 public:
 	mglBase *gr;	///< mglBase class used for drawing characters
-	mglFont(const char *name=0, const char *path=0);
+	mglFont();
+	mglFont(const char *name, const char *path=0);
 	virtual ~mglFont();
 	bool parse;		///< Parse LaTeX symbols
 
@@ -99,6 +100,8 @@ public:
 	/// Get width of text string for font specified by string
 	float Width(const wchar_t *str,const char *how, float *y1=0, float *y2=0) const;
 
+	/// Set height scaling factor
+	inline void HeightScale(float s=1)	{	Hscale = s>0?s:1;	}
 	/// Get internal code for symbol
 	inline long Internal(unsigned s) const	{	return mgl_internal_code(s,glyphs);	}
 	/// Return number of glyphs
@@ -115,7 +118,8 @@ protected:
 	std::vector<mglGlyphDescr> glyphs;	///< information about know glyphs
 	float fact[4];	///< Divider for width of glyph
 	short *Buf;		///< Buffer for glyph descriptions
-	size_t numb;		///< Buffer size
+	size_t numb;	///< Buffer size
+	float Hscale;	///< Height scaling
 
 	/// Print text string for font specified by integer constant
 	float Puts(const wchar_t *str,int font,int align, float c1,float c2) const;
