@@ -2,7 +2,7 @@
  * Copyright (C) 2007-2014 Alexey Balakin <mathgl.abalakin@gmail.ru>
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public License
+ * modify it under the terms of the GNU Lesser General Public License 
  * as published by the Free Software Foundation
  *
  * This program is distributed in the hope that it will be useful,
@@ -41,20 +41,24 @@ Fl_Text_Display::Style_Table_Entry styletable[10] = {	// Style table
 		{ FL_DARK_CYAN,	FL_COURIER,		14, 0 },		// F - Flow command
 		{ FL_DARK_MAGENTA,	FL_COURIER,	14, 0 },		// G - New-data command
 		{ FL_DARK_RED,	FL_COURIER,		14, 0 },		// H - Option
-		{ FL_DARK_GREEN,FL_COURIER,		14, 0 },		// I - Inactive command
+		{ FL_GRAY,		FL_COURIER,		14, 0 },		// I - Inactive command
 		{ FL_MAGENTA,	FL_COURIER,		14, 0 }			// J - Error line ???
 	};
 int font_kind;	///< Editor font kind
 int font_size;	///< Editor font size
 //-----------------------------------------------------------------------------
-void set_style(int kind, int size)
+void set_style(int kind, int size, int fdark)
 {
+	Fl_Color c1[10]={FL_BLACK,FL_DARK_GREEN,FL_BLUE,FL_RED,FL_DARK_BLUE,FL_DARK_CYAN,FL_DARK_MAGENTA,FL_DARK_RED,FL_GRAY,FL_MAGENTA};
+	Fl_Color c2[10]={FL_WHITE,FL_GREEN,FL_CYAN,FL_YELLOW,FL_BLUE,FL_CYAN,FL_MAGENTA,FL_RED,FL_GRAY,FL_MAGENTA};
 	if(kind<0 || kind>2)	kind = 1;
 	if(size<1)	size = 14;
 	for(int i=0;i<10;i++)	// set font for styles
 	{	styletable[i].size = size;	styletable[i].font = 4*kind;	}
 	styletable[1].font = 4*kind+2;
 	font_kind = kind;	font_size = size;
+	if(fdark)	for(int i=0;i<10;i++)	styletable[i].color = c2[i];
+	else		for(int i=0;i<10;i++)	styletable[i].color = c1[i];
 }
 //-----------------------------------------------------------------------------
 bool MGL_FUNC_PURE is_sfx(const char *s)	// suffix
@@ -482,12 +486,12 @@ void changed_cb(int pos, int nInserted, int nDeleted, int nRestyled, const char
 	if (loading) w->editor->show_insert_position();
 }
 //-----------------------------------------------------------------------------
-void insert_cb(Fl_Widget*, void *v)
-{
-	const char *newfile = mgl_file_chooser(_("Insert file content?"));
-	ScriptWindow *w = (ScriptWindow *)v;
-	if (newfile != NULL) load_file(newfile, w->editor->insert_position(),w);
-}
+// void insert_cb(Fl_Widget*, void *v)
+// {
+// 	const char *newfile = mgl_file_chooser(_("Insert file content?"));
+// 	ScriptWindow *w = (ScriptWindow *)v;
+// 	if (newfile != NULL) load_file(newfile, w->editor->insert_position(),w);
+// }
 //-----------------------------------------------------------------------------
 void paste_cb(Fl_Widget*, void* v)
 {
@@ -525,7 +529,7 @@ Fl_Widget *add_editor(ScriptWindow *w, int txtW, int wndH)
 	o = new Fl_Button(210, 1, 25, 25);	o->image(img_calc);	o->callback(calc_dlg_cb,w);
 	o->tooltip(_("Show calculator window"));
 	o = new Fl_Button(240, 1, 25, 25);	o->image(img_curve);o->callback(prim_dlg_cb,w);
-	o->tooltip(_("Show calculator window"));
+	o->tooltip(_("Show window for primitives"));
 	g->end();	g->resizable(0);
 
 	w->editor = new Fl_Text_Editor(0, 28, txtW, wndH-85);
