@@ -2,7 +2,7 @@
  * Copyright (C) 2007-2014 Alexey Balakin <mathgl.abalakin@gmail.ru>
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public License
+ * modify it under the terms of the GNU Lesser General Public License 
  * as published by the Free Software Foundation
  *
  * This program is distributed in the hope that it will be useful,
@@ -382,7 +382,7 @@ public:
 			case 0:	*out = c->Sum(r);	break;
 			case 1:	*out = c->Max(r);	break;
 			case 2:	*out = c->Min(r);	break;
-			case 3:	out = mgl_data_pulse(c,*r);	break;
+			case 3:	*out = mglData(true,mgl_data_pulse(c,*r));	break;
 		}
 		hide();
 	}
@@ -559,8 +559,8 @@ public:
 		o->tooltip(_("Change data values and close this window"));
 		w->set_modal();	w->end();
 	}
-	double min()	{	return wmin->value();	}
-	double max()	{	return wmax->value();	}
+	double vmin()	{	return wmin->value();	}
+	double vmax()	{	return wmax->value();	}
 	int sym()		{	return wsym->value();	}
 	bool ok()		{	return !result.empty();	}
 	void cb_ok()
@@ -581,8 +581,8 @@ void fill_cb(Fl_Widget*, void*v)
 		HMDT d = dynamic_cast<HMDT>(e->var);
 		HADT c = dynamic_cast<HADT>(e->var);
 		char ch = nrm_dlg.result[0];
-		if(d)	{	d->Fill(nrm_dlg.min(),nrm_dlg.max(),ch);	e->refresh();	}
-		if(c)	{	c->Fill(nrm_dlg.min(),nrm_dlg.max(),ch);	e->refresh();	}
+		if(d)	{	d->Fill(nrm_dlg.vmin(),nrm_dlg.vmax(),ch);	e->refresh();	}
+		if(c)	{	c->Fill(nrm_dlg.vmin(),nrm_dlg.vmax(),ch);	e->refresh();	}
 	}
 }
 //-----------------------------------------------------------------------------
@@ -594,8 +594,8 @@ void normal_cb(Fl_Widget*, void*v)
 	{
 		HMDT d = dynamic_cast<HMDT>(e->var);
 		HADT c = dynamic_cast<HADT>(e->var);
-		if(d)	{	d->Norm(nrm_dlg.min(),nrm_dlg.max(),nrm_dlg.sym());	e->refresh();	}
-		if(c)	{	c->Fill(nrm_dlg.min(),nrm_dlg.max(),nrm_dlg.sym());	e->refresh();	}
+		if(d)	{	d->Norm(nrm_dlg.vmin(),nrm_dlg.vmax(),nrm_dlg.sym());	e->refresh();	}
+		if(c)	{	c->Fill(nrm_dlg.vmin(),nrm_dlg.vmax(),nrm_dlg.sym());	e->refresh();	}
 	}
 }
 //-----------------------------------------------------------------------------
