@@ -247,7 +247,7 @@ GifFileType *gif;*/
 	SetPlotFactor(0);	Sub.clear();
 	InPlot(0,1,0,1,false);	clr(MGL_FULL_CURV);
 	SetTickLen(0);	SetCut(true);
-	AdjustTicks("xyzc",true);	Clf('w');
+	AdjustTicks("xyzc",true);	Clf(mglColor(1,1,1,0));
 
 	for(int i=0;i<10;i++)	{	AddLight(i, mglPoint(0,0,1));	Light(i,false);	}
 	Light(0,true);	Light(false);	SetDifLight(true);
@@ -261,7 +261,7 @@ mreal mglCanvas::FindOptOrg(char dir, int ind) const
 	static mglMatrix bb;
 	mglPoint nn[8]={mglPoint(0,0,0), mglPoint(0,0,1), mglPoint(0,1,0,0), mglPoint(0,1,1),
 					mglPoint(1,0,0), mglPoint(1,0,1), mglPoint(1,1,0), mglPoint(1,1,1)}, pp[8];
-	memcpy(pp, nn, 8*sizeof(mglPoint));
+	memcpy((void*)pp, nn, 8*sizeof(mglPoint));
 	// do nothing if transformation matrix is the same
 	if(B!=bb)
 	{
@@ -342,6 +342,55 @@ mreal mglCanvas::GetOrgZ(char dir, bool inv) const
 	return res;
 }
 //-----------------------------------------------------------------------------
+long mglCanvas::AddPairBnd(const mglPnt &q1, const mglPnt &q2)
+{
+	mglPnt q;
+	mreal p1[3],p2[3], x,y,z;
+	const float *b = B.ib, f = 1/(2*B.pf);
+	x = (q1.xx-B.x)/f;	y = (q1.yy-B.y)/f;	z = (q1.zz-B.z)/f;
+	p1[0] = x*b[0] + y*b[1] + z*b[2];
+	p1[1] = x*b[3] + y*b[4] + z*b[5];
+	p1[2] = x*b[6] + y*b[7] + z*b[8];
+	x = (q2.xx-B.x)/f;	y = (q2.yy-B.y)/f;	z = (q2.zz-B.z)/f;
+	p2[0] = x*b[0] + y*b[1] + z*b[2] - p1[0];
+	p2[1] = x*b[3] + y*b[4] + z*b[5] - p1[1];
+	p2[2] = x*b[6] + y*b[7] + z*b[8] - p1[2];
+	const mreal eps = 1e-5;
+	mreal s=1,ss;
+	if(fabs(p2[0])>eps)
+	{
+		ss = -(1+p1[0])/p2[0];	if(ss>eps && ss<s)	s=ss;
+		ss = (1-p1[0])/p2[0];	if(ss>eps && ss<s)	s=ss;
+	}
+	if(fabs(p2[1])>eps)
+	{
+		ss = -(1+p1[1])/p2[1];	if(ss>eps && ss<s)	s=ss;
+		ss = (1-p1[1])/p2[1];	if(ss>eps && ss<s)	s=ss;
+	}
+	if(fabs(p2[2])>eps)
+	{
+		ss = -(1+p1[2])/p2[2];	if(ss>eps && ss<s)	s=ss;
+		ss = (1-p1[2])/p2[2];	if(ss>eps && ss<s)	s=ss;
+	}
+	if(s>1-eps)	return -1;
+	q.x = q.xx = q1.xx + s*(q2.xx-q1.xx);
+	q.y = q.yy = q1.yy + s*(q2.yy-q1.yy);
+	q.z = q.zz = q1.zz + s*(q2.zz-q1.zz);
+	q.u = q1.u + s*(q2.u-q1.u);
+	q.v = q1.v + s*(q2.v-q1.v);
+	q.w = q1.w + s*(q2.w-q1.w);
+	q.r = q1.r + s*(q2.r-q1.r);
+	q.g = q1.g + s*(q2.g-q1.g);
+	q.b = q1.b + s*(q2.b-q1.b);
+	q.a = q1.a + s*(q2.a-q1.a);
+	q.c = q1.c + s*(q2.c-q1.c);
+	q.ta = q1.ta + s*(q2.ta-q1.ta);
+	long k;
+#pragma omp critical(pnt)
+	{k=Pnt.size();	MGL_PUSH(Pnt,q,mutexPnt);}
+	return k;
+}
+//-----------------------------------------------------------------------------
 //	Put primitives
 //-----------------------------------------------------------------------------
 #define MGL_MARK_PLOT	if(Quality&MGL_DRAW_LMEM)	\
@@ -371,9 +420,19 @@ void mglCanvas::mark_plot(long p, char type, mreal size)
 							a.n1 = p1;	a.n2 = p2;	a.w = pw;	a.angl=0;	add_prim(a);	}
 void mglCanvas::line_plot(long p1, long p2)
 {
-	if(PDef==0)	return;
-	if(SamePnt(p1,p2))	return;
-	if(p1>p2)	{	long kk=p1;	p1=p2;	p2=kk;	}	// rearrange start/end for proper dashing
+	if(PDef==0 || p1<0 || p2<0)	return;	// nothing to do
+	if(!(Flag&MGL_FAST_PRIM) && !(TernAxis&3))
+	{
+		if(p1>p2)	{	long kk=p1;	p1=p2;	p2=kk;	}	// rearrange start/end for proper dashing
+		const mglPnt &q1=Pnt[p1], &q2=Pnt[p2];
+		if(q1.x==q2.x && q1.y==q2.y)	return;	// the same points
+		if(mgl_isnan(q1.x) && mgl_isnum(q2.x))
+			p1 = AddPairBnd(q2,q1);
+		if(mgl_isnum(q1.x) && mgl_isnan(q2.x))
+			p2 = AddPairBnd(q1,q2);
+	}
+	if(p1<0 || p2<0 || mgl_isnan(Pnt[p1].x) || mgl_isnan(Pnt[p2].x))	return;
+
 	long pp1=p1,pp2=p2;
 	mreal pw = fabs(PenWidth)*sqrt(font_factor/400), d=0;
 	if(TernAxis&12) for(int i=0;i<4;i++)
@@ -398,35 +457,278 @@ void mglCanvas::line_plot(long p1, long p2)
 							trig_draw(Pnt[p1],Pnt[p2],Pnt[p3],true,&d);	}\
 						else{	mglPrim a(2);	a.n1 = p1;	a.n2 = p2;	a.n3 = p3;	\
 							a.m=mask;	a.angl=MaskAn;	a.w = pw;	add_prim(a);}
-void mglCanvas::trig_plot(long p1, long p2, long p3)
-{
-	if(SamePnt(p1,p2) || SamePnt(p1,p3))	return;
-	long pp1=p1,pp2=p2,pp3=p3;
-	mreal pw = fabs(PenWidth)*sqrt(font_factor/400);
-	if(TernAxis&12) for(int i=0;i<4;i++)
-	{	p1 = ProjScale(i, pp1);	p2 = ProjScale(i, pp2);
-		p3 = ProjScale(i, pp3);	if(p1>=0&&p2>=0&&p3>=0)	{MGL_TRIG_PLOT}	}
-	else	{	MGL_TRIG_PLOT	}
-}
-//-----------------------------------------------------------------------------
 #define MGL_QUAD_PLOT	if(Quality&MGL_DRAW_LMEM)	\
 						{	mglDrawReg d;	d.set(this,dr_x,dr_y,dr_p);	d.PenWidth=pw;	\
 							quad_draw(Pnt[p1],Pnt[p2],Pnt[p3],Pnt[p4],&d);	}\
 						else{	mglPrim a(3);	a.n1 = p1;	a.n2 = p2;	a.n3 = p3;	a.n4 = p4;	\
 							a.m=mask;	a.angl=MaskAn;	a.w = pw;	add_prim(a);	}
+#define MGL_ADD_TRIG	{	long pp1=p1,pp2=p2,pp3=p3;	\
+						mreal pw = fabs(PenWidth)*sqrt(font_factor/400);	\
+						if(TernAxis&12) for(int i=0;i<4;i++)	\
+						{	p1 = ProjScale(i, pp1);	p2 = ProjScale(i, pp2);	\
+							p3 = ProjScale(i, pp3);	if(p1>=0&&p2>=0&&p3>=0)	{MGL_TRIG_PLOT}	}	\
+						else	{	MGL_TRIG_PLOT	}	}
+#define MGL_ADD_QUAD	{	long pp1=p1,pp2=p2,pp3=p3,pp4=p4;	\
+						mreal pw = fabs(PenWidth)*sqrt(font_factor/400);		\
+						if(TernAxis&12) for(int i=0;i<4;i++)	\
+						{	p1 = ProjScale(i, pp1);	p2 = ProjScale(i, pp2);		\
+							p3 = ProjScale(i, pp3);	p4 = ProjScale(i, pp4);		\
+							if(p1>=0&&p2>=0&&p3>=0&&p4>=0)	{MGL_QUAD_PLOT}	}	\
+						else	{	MGL_QUAD_PLOT	}	}
+
+
+void mglCanvas::trig_plot(long p1, long p2, long p3)
+{
+	if(p1<0 || p2<0 || p3<0)	return;	// nothing to do
+	const mglPnt &q1=Pnt[p1], &q2=Pnt[p2], &q3=Pnt[p3];
+	long state = (mgl_isnan(q1.x)?1:0)+(mgl_isnan(q2.x)?2:0)+(mgl_isnan(q3.x)?4:0), st, p4;
+	if((Flag&MGL_FAST_PRIM) || (TernAxis&3))
+	{
+		if(!state)	MGL_ADD_TRIG
+	}
+	else switch(state)
+	{
+	case 0:	MGL_ADD_TRIG	break;
+	case 1:
+		p1 = AddPairBnd(q2,q1);
+		p4 = p3;
+		p3 = AddPairBnd(q3,q1);
+		st = ((p1>=0 && mgl_isnum(Pnt[p1].x))?0:1)+((p3>=0 && mgl_isnum(Pnt[p3].x))?0:2);
+		switch(st)
+		{
+			case 0:	MGL_ADD_QUAD	break;
+			case 1:	p1 = p4;	MGL_ADD_TRIG	break;
+			case 2:	p3 = p4;	MGL_ADD_TRIG	break;
+		}
+		break;
+	case 2:
+		p2 = AddPairBnd(q1,q2);
+		p4 = AddPairBnd(q3,q2);
+		st = ((p2>=0 && mgl_isnum(Pnt[p2].x))?0:1)+((p4>=0 && mgl_isnum(Pnt[p4].x))?0:2);
+		switch(st)
+		{
+			case 0:	MGL_ADD_QUAD	break;
+			case 1:	p2 = p4;	MGL_ADD_TRIG	break;
+			case 2:	MGL_ADD_TRIG	break;
+		}
+		break;
+	case 3:
+		p1 = AddPairBnd(q3,q1);
+		p2 = AddPairBnd(q3,q2);
+		if(p2>=0 && p1>=0 && mgl_isnum(Pnt[p2].x) && mgl_isnum(Pnt[p1].x))	// valid trig
+			MGL_ADD_TRIG
+		break;
+	case 4:
+		p3 = AddPairBnd(q1,q3);
+		p4 = AddPairBnd(q2,q3);
+		st = ((p3>=0 && mgl_isnum(Pnt[p3].x))?0:1)+((p4>=0 && mgl_isnum(Pnt[p4].x))?0:2);
+		switch(st)
+		{
+			case 0:	MGL_ADD_QUAD	break;
+			case 1:	p3 = p4;	MGL_ADD_TRIG	break;
+			case 2:	MGL_ADD_TRIG	break;
+		}
+		break;
+	case 5:
+		p1 = AddPairBnd(q2,q1);
+		p3 = AddPairBnd(q2,q3);
+		if(p1>=0 && p3>=0 && mgl_isnum(Pnt[p1].x) && mgl_isnum(Pnt[p3].x))	// valid trig
+			MGL_ADD_TRIG
+		break;
+	case 6:
+		p2 = AddPairBnd(q1,q2);
+		p3 = AddPairBnd(q1,q3);
+		if(p2>=0 && p3>=0 && mgl_isnum(Pnt[p2].x) && mgl_isnum(Pnt[p3].x))	// valid trig
+			MGL_ADD_TRIG
+		break;
+	}
+}
+//-----------------------------------------------------------------------------
 void mglCanvas::quad_plot(long p1, long p2, long p3, long p4)
 {
-	if(SamePnt(p1,p2))	{	trig_plot(p4,p2,p3);	return;	}
-	if(SamePnt(p2,p4))	{	trig_plot(p1,p4,p3);	return;	}
-	if(SamePnt(p1,p3))	{	trig_plot(p1,p2,p4);	return;	}
-	if(SamePnt(p3,p4))	{	trig_plot(p1,p2,p3);	return;	}
-	long pp1=p1,pp2=p2,pp3=p3,pp4=p4;
-	mreal pw = fabs(PenWidth)*sqrt(font_factor/400);
-	if(TernAxis&12) for(int i=0;i<4;i++)
-	{	p1 = ProjScale(i, pp1);	p2 = ProjScale(i, pp2);
-		p3 = ProjScale(i, pp3);	p4 = ProjScale(i, pp4);
-		if(p1>=0&&p2>=0&&p3>=0&&p4>=0)	{MGL_QUAD_PLOT}	}
-	else	{	MGL_QUAD_PLOT	}
+	if(p1<0)	{	trig_plot(p4,p2,p3);	return;	}
+	if(p2<0)	{	trig_plot(p1,p4,p3);	return;	}
+	if(p3<0)	{	trig_plot(p1,p2,p4);	return;	}
+	if(p4<0)	{	trig_plot(p1,p2,p3);	return;	}
+	const mglPnt &q1=Pnt[p1], &q2=Pnt[p2], &q3=Pnt[p3], &q4=Pnt[p4];
+	int state = (mgl_isnan(q1.x)?1:0)+(mgl_isnan(q2.x)?2:0)+(mgl_isnan(q3.x)?4:0)+(mgl_isnan(q4.x)?8:0), st;
+	if((Flag&MGL_FAST_PRIM) || (TernAxis&3))
+	{
+		switch(state)
+		{
+		case 0:	MGL_ADD_QUAD	break;
+		case 1:	p1 = p4;	MGL_ADD_TRIG	break;
+		case 2:	p2 = p4;	MGL_ADD_TRIG	break;
+		case 4:	p3 = p4;	MGL_ADD_TRIG	break;
+		case 8:	MGL_ADD_TRIG	break;
+		}
+	}
+	else switch(state)
+	{
+	case 0:	MGL_ADD_QUAD	break;
+	case 1:
+		p1 = p4;	MGL_ADD_TRIG	// valid trig
+		p1 = AddPairBnd(q2,q1);	p4=p3;	p3=p2;
+		p2 = AddPairBnd(q3,q1);
+		st = ((p1>=0 && mgl_isnum(Pnt[p1].x))?0:1)+((p2>=0 && mgl_isnum(Pnt[p2].x))?0:2);
+		switch(st)
+		{
+			case 0:	MGL_ADD_QUAD	break;
+			case 1:	p1 = p4;	MGL_ADD_TRIG	break;
+			case 2:	p2 = p4;	MGL_ADD_TRIG	break;
+		}
+		break;
+	case 2:
+		p2 = p4;	MGL_ADD_TRIG	// valid trig
+		p3 = AddPairBnd(q1,q2);
+		p4 = AddPairBnd(q4,q2);
+		st = ((p3>=0 && mgl_isnum(Pnt[p3].x))?0:1)+((p4>=0 && mgl_isnum(Pnt[p4].x))?0:2);
+		switch(st)
+		{
+			case 0:	MGL_ADD_QUAD	break;
+			case 1:	p3 = p4;	MGL_ADD_TRIG	break;
+			case 2:	MGL_ADD_TRIG	break;
+		}
+		break;
+	case 3:
+		p1 = AddPairBnd(q3,q1);
+		p2 = AddPairBnd(q4,q2);
+		st = ((p1>=0 && mgl_isnum(Pnt[p1].x))?0:1)+((p2>=0 && mgl_isnum(Pnt[p2].x))?0:2);
+		switch(st)
+		{
+			case 0:	MGL_ADD_QUAD	break;
+			case 1:	p1 = p4;	MGL_ADD_TRIG	break;
+			case 2:	p2 = p4;	MGL_ADD_TRIG	break;
+		}
+		break;
+	case 4:
+		p3 = p4;	MGL_ADD_TRIG	// valid trig
+		p2 = AddPairBnd(q1,q3);
+		p4 = AddPairBnd(q4,q3);
+		st = ((p2>=0 && mgl_isnum(Pnt[p2].x))?0:1)+((p4>=0 && mgl_isnum(Pnt[p4].x))?0:2);
+		switch(st)
+		{
+			case 0:	MGL_ADD_QUAD	break;
+			case 1:	p2 = p4;	MGL_ADD_TRIG	break;
+			case 2:	MGL_ADD_TRIG	break;
+		}
+		break;
+	case 5:
+		p1 = AddPairBnd(q2,q1);
+		p3 = AddPairBnd(q4,q3);
+		st = ((p1>=0 && mgl_isnum(Pnt[p1].x))?0:1)+((p3>=0 && mgl_isnum(Pnt[p3].x))?0:2);
+		switch(st)
+		{
+			case 0:	MGL_ADD_QUAD	break;
+			case 1:	p1 = p4;	MGL_ADD_TRIG	break;
+			case 2:	p3 = p4;	MGL_ADD_TRIG	break;
+		}
+		break;
+	case 6:
+		p2 = AddPairBnd(q1,q2);	p3=p4;
+		p4 = AddPairBnd(q4,q2);
+		st = ((p4>=0 && mgl_isnum(Pnt[p4].x))?0:1)+((p2>=0 && mgl_isnum(Pnt[p2].x))?0:2);
+		switch(st)
+		{
+			case 0:	MGL_ADD_QUAD	break;
+			case 1:	MGL_ADD_TRIG	break;
+			case 2:	p2 = p4;	MGL_ADD_TRIG	break;
+		}
+		p2 = AddPairBnd(q1,q3);
+		p4 = AddPairBnd(q4,q3);
+		st = ((p4>=0 && mgl_isnum(Pnt[p4].x))?0:1)+((p2>=0 && mgl_isnum(Pnt[p2].x))?0:2);
+		switch(st)
+		{
+			case 0:	MGL_ADD_QUAD	break;
+			case 1:	MGL_ADD_TRIG	break;
+			case 2:	p2 = p4;	MGL_ADD_TRIG	break;
+		}
+		break;
+	case 7:
+		p1 = p4;
+		p2 = AddPairBnd(q4,q2);
+		p3 = AddPairBnd(q4,q3);
+		if(p3>=0 && p2>=0 && mgl_isnum(Pnt[p3].x) && mgl_isnum(Pnt[p2].x))	// valid trig
+			MGL_ADD_TRIG
+		break;
+	case 8:
+		MGL_ADD_TRIG
+		p1 = AddPairBnd(q2,q4);	p4=p3;	p3=p2;
+		p2 = AddPairBnd(q3,q4);
+		st = ((p1>=0 && mgl_isnum(Pnt[p1].x))?0:1)+((p2>=0 && mgl_isnum(Pnt[p2].x))?0:2);
+		switch(st)
+		{
+			case 0:	MGL_ADD_QUAD	break;
+			case 1:	p1 = p4;	MGL_ADD_TRIG	break;
+			case 2:	p2 = p4;	MGL_ADD_TRIG	break;
+		}
+		break;
+	case 9:
+		p1 = AddPairBnd(q3,q1);	p4=p2;
+		p2 = AddPairBnd(q2,q1);
+		st = ((p1>=0 && mgl_isnum(Pnt[p1].x))?0:1)+((p2>=0 && mgl_isnum(Pnt[p2].x))?0:2);
+		switch(st)
+		{
+			case 0:	MGL_ADD_QUAD	break;
+			case 1:	p1 = p4;	MGL_ADD_TRIG	break;
+			case 2:	p2 = p4;	MGL_ADD_TRIG	break;
+		}
+		p1 = AddPairBnd(q3,q4);
+		p2 = AddPairBnd(q2,q4);
+		st = ((p1>=0 && mgl_isnum(Pnt[p1].x))?0:1)+((p2>=0 && mgl_isnum(Pnt[p2].x))?0:2);
+		switch(st)
+		{
+			case 0:	MGL_ADD_QUAD	break;
+			case 1:	p1 = p4;	MGL_ADD_TRIG	break;
+			case 2:	p2 = p4;	MGL_ADD_TRIG	break;
+		}
+		break;
+	case 10:
+		p2 = AddPairBnd(q1,q2);
+		p4 = AddPairBnd(q3,q4);
+		st = ((p2>=0 && mgl_isnum(Pnt[p2].x))?0:1)+((p4>=0 && mgl_isnum(Pnt[p4].x))?0:2);
+		switch(st)
+		{
+			case 0:	MGL_ADD_QUAD	break;
+			case 1:	p2 = p4;	MGL_ADD_TRIG	break;
+			case 2:	MGL_ADD_TRIG	break;
+		}
+		break;
+	case 11:
+		p1 = AddPairBnd(q3,q1);
+		p2 = AddPairBnd(q3,q4);
+		if(p1>=0 && p2>=0 && mgl_isnum(Pnt[p1].x) && mgl_isnum(Pnt[p2].x))	// valid trig
+			MGL_ADD_TRIG
+		break;
+	case 12:
+		p3 = AddPairBnd(q1,q3);
+		p4 = AddPairBnd(q2,q4);
+		st = ((p3>=0 && mgl_isnum(Pnt[p3].x))?0:1)+((p4>=0 && mgl_isnum(Pnt[p4].x))?0:2);
+		switch(st)
+		{
+			case 0:	MGL_ADD_QUAD	break;
+			case 1:	p3 = p4;	MGL_ADD_TRIG	break;
+			case 2:	MGL_ADD_TRIG	break;
+		}
+		break;
+	case 13:
+		p1 = AddPairBnd(q2,q1);
+		p3 = AddPairBnd(q2,q4);
+		if(p3>=0 && p1>=0 && mgl_isnum(Pnt[p3].x) && mgl_isnum(Pnt[p1].x))	// valid trig
+			MGL_ADD_TRIG
+		break;
+	case 14:
+		p2 = AddPairBnd(q1,q2);
+		p3 = AddPairBnd(q1,q3);
+		st = ((p2>=0 && mgl_isnum(Pnt[p2].x))?0:1)+((p3>=0 && mgl_isnum(Pnt[p3].x))?0:2);
+		switch(st)
+		{
+			case 0:	MGL_ADD_QUAD	break;
+			case 1:	p2 = p4;	MGL_ADD_TRIG	break;
+			case 2:	p3 = p4;	MGL_ADD_TRIG	break;
+		}
+		break;
+	}
 }
 //-----------------------------------------------------------------------------
 mreal mglCanvas::text_plot(long p,const wchar_t *text,const char *font,mreal size,mreal sh,mreal col,bool rot)
@@ -515,6 +817,7 @@ pthread_mutex_lock(&mutexPtx);
 		q.u = q.v = NAN;	q.a=q.ta=1;
 		memset(Bt.b,0,9*sizeof(float));
 		Bt.b[0] = Bt.b[4] = Bt.b[8] = fscl;
+		Bt.ib[0] = Bt.ib[4] = Bt.ib[8] = 1./fscl;
 		float opf = Bt.pf;
 		Bt.RotateN(ftet,0,0,1);	Bt.pf = Bt.norot?1.55:opf;
 		if(strchr(font,'@'))	// draw box around text
@@ -635,6 +938,7 @@ void mglCanvas::InPlot(mreal x1,mreal x2,mreal y1,mreal y2, const char *st)
 	B.b[0] = Width*(x2-x1);	B.b[4] = Height*(y2-y1);
 	B.b[8] = sqrt(B.b[0]*B.b[4]);
 	B.z = (1.f-B.b[8]/(2*Depth))*Depth;
+	B.invert();
 	B1=B;	font_factor = B.b[0] < B.b[4] ? B.b[0] : B.b[4];
 
 	mglBlock p;	p.AmbBr = AmbBr;	p.DifBr = DifBr;	p.B = B;
@@ -656,6 +960,7 @@ void mglCanvas::InPlot(mglMatrix &M,mreal x1,mreal x2,mreal y1,mreal y2, bool re
 		M.b[0] = B1.b[0]*(x2-x1);	M.b[4] = B1.b[4]*(y2-y1);
 		M.b[8] = sqrt(M.b[0]*M.b[4]);
 		M.z = B1.z + (1.f-M.b[8]/(2*Depth))*B1.b[8];
+		M.invert();
 	}
 	else
 	{
@@ -664,7 +969,7 @@ void mglCanvas::InPlot(mglMatrix &M,mreal x1,mreal x2,mreal y1,mreal y2, bool re
 		M.b[0] = Width*(x2-x1);	M.b[4] = Height*(y2-y1);
 		M.b[8] = sqrt(M.b[0]*M.b[4]);
 		M.z = (1.f-M.b[8]/(2*Depth))*Depth;
-		B1=M;
+		M.invert();	B1=M;
 	}
 	inW=M.b[0];	inH=M.b[4];	ZMin=1;
 	inX=Width*x1;	inY=Height*y1;
@@ -730,6 +1035,7 @@ void mglMatrix::Rotate(mreal tetz,mreal tetx,mreal tety)
 	b[6] = R[0]*O[6] + R[3]*O[7] + R[6]*O[8];
 	b[7] = R[1]*O[6] + R[4]*O[7] + R[7]*O[8];
 	b[8] = R[2]*O[6] + R[5]*O[7] + R[8]*O[8];
+	invert();
 }
 //-----------------------------------------------------------------------------
 void mglCanvas::RotateN(mreal Tet,mreal x,mreal y,mreal z)
@@ -761,6 +1067,7 @@ void mglMatrix::RotateN(mreal Tet,mreal vx,mreal vy,mreal vz)
 	b[6] = T[0]*R[6] + T[3]*R[7] + T[6]*R[8];
 	b[7] = T[1]*R[6] + T[4]*R[7] + T[7]*R[8];
 	b[8] = T[2]*R[6] + T[5]*R[7] + T[8]*R[8];
+	invert();
 }
 //-----------------------------------------------------------------------------
 void mglCanvas::View(mreal tetx,mreal tetz,mreal tety)
@@ -773,6 +1080,7 @@ void mglCanvas::Zoom(mreal x1, mreal y1, mreal x2, mreal y2)
 	x1=2*x1-1;	x2=2*x2-1;	y1=2*y1-1;	y2=2*y2-1;
 	Bp.b[0]=2/fabs(x2-x1);	Bp.b[4]=2/fabs(y2-y1);
 	Bp.x=(x1+x2)/fabs(x2-x1);Bp.y=(y1+y2)/fabs(y2-y1);
+	Bp.invert();
 }
 //-----------------------------------------------------------------------------
 int mglCanvas::GetSplId(long x,long y) const
@@ -808,6 +1116,7 @@ void mglCanvas::Aspect(mreal Ax,mreal Ay,mreal Az)
 	B.b[0] *= Ax;	B.b[3] *= Ax;	B.b[6] *= Ax;
 	B.b[1] *= Ay;	B.b[4] *= Ay;	B.b[7] *= Ay;
 	B.b[2] *= Az;	B.b[5] *= Az;	B.b[8] *= Az;
+	B.invert();
 	size_t n = Sub.size();	if(n>0)	Sub[n-1].B = B;
 }
 //-----------------------------------------------------------------------------
@@ -817,6 +1126,7 @@ void mglCanvas::Shear(mreal Sx,mreal Sy)
 	const float R[6]={B.b[0],B.b[1],B.b[2],B.b[3],B.b[4],B.b[5]};
 	B.b[0] = (R[0]+Sx*R[3])/Fx;	B.b[1] = (R[1]+Sx*R[4])/Fx;	B.b[2] = (R[2]+Sx*R[5])/Fx;
 	B.b[3] = (R[3]+Sy*R[0])/Fy;	B.b[4] = (R[4]+Sy*R[1])/Fy;	B.b[5] = (R[5]+Sy*R[2])/Fy;
+	B.invert();
 	size_t n = Sub.size();	if(n>0)	Sub[n-1].B = B;
 }
 //-----------------------------------------------------------------------------
