@@ -3,7 +3,7 @@
  * Copyright (C) 2007-2016 Alexey Balakin <mathgl.abalakin@gmail.ru>       *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU Library General Public License as       *
+ *   it under the terms of the GNU Lesser General Public License  as       *
  *   published by the Free Software Foundation; either version 3 of the    *
  *   License, or (at your option) any later version.                       *
  *                                                                         *
@@ -12,7 +12,7 @@
  *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
  *   GNU General Public License for more details.                          *
  *                                                                         *
- *   You should have received a copy of the GNU Library General Public     *
+ *   You should have received a copy of the GNU Lesser General Public     *
  *   License along with this program; if not, write to the                 *
  *   Free Software Foundation, Inc.,                                       *
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
@@ -33,18 +33,20 @@ mglCommand *mglParser::BaseCmd=NULL;	///< Base table of MGL commands. It MUST be
 void mglParser::FillBaseCmd()
 {
 	if(BaseCmd)	return;
-	size_t na=0, nd=0, ng=0, np=0, ns=0, nsum=0;
+	size_t na=0, nd=0, ng=0, np=0, ns=0, nr=0, nsum=0;
 	while(mgls_prg_cmd[na].name[0])	na++;
 	while(mgls_dat_cmd[nd].name[0])	nd++;
 	while(mgls_grf_cmd[ng].name[0])	ng++;
 	while(mgls_prm_cmd[np].name[0])	np++;
 	while(mgls_set_cmd[ns].name[0])	ns++;
-	BaseCmd = new mglCommand[na+nd+ng+np+ns+1];
+	while(mgls_rnd_cmd[nr].name[0])	nr++;
+	BaseCmd = new mglCommand[na+nd+ng+np+ns+nr+1];
 	memcpy(BaseCmd, 	mgls_prg_cmd, na*sizeof(mglCommand));	nsum+=na;
 	memcpy(BaseCmd+nsum,mgls_dat_cmd, nd*sizeof(mglCommand));	nsum+=nd;
 	memcpy(BaseCmd+nsum,mgls_grf_cmd, ng*sizeof(mglCommand));	nsum+=ng;
 	memcpy(BaseCmd+nsum,mgls_prm_cmd, np*sizeof(mglCommand));	nsum+=np;
-	memcpy(BaseCmd+nsum,mgls_set_cmd, (ns+1)*sizeof(mglCommand));	nsum+=ns;
+	memcpy(BaseCmd+nsum,mgls_rnd_cmd, nr*sizeof(mglCommand));	nsum+=nr;
+	memcpy(BaseCmd+nsum,mgls_set_cmd,(ns+1)*sizeof(mglCommand));nsum+=ns;
 	qsort(BaseCmd, nsum, sizeof(mglCommand), mgl_cmd_cmp);
 #if DEBUG
 	long stat[17];	memset(stat,0,17*sizeof(long));
@@ -55,8 +57,8 @@ void mglParser::FillBaseCmd()
 #endif
 }
 //-----------------------------------------------------------------------------
-HMDT MGL_NO_EXPORT mglFormulaCalc(std::wstring string, mglParser *arg, const std::vector<mglDataA*> &head);
-HADT MGL_NO_EXPORT mglFormulaCalcC(std::wstring string, mglParser *arg, const std::vector<mglDataA*> &head);
+HMDT MGL_NO_EXPORT mglFormulaCalc(const std::wstring &string, mglParser *arg, const std::vector<mglDataA*> &head);
+HADT MGL_NO_EXPORT mglFormulaCalcC(const std::wstring &string, mglParser *arg, const std::vector<mglDataA*> &head);
 //-----------------------------------------------------------------------------
 MGL_EXPORT void (*mgl_ask_func)(const wchar_t *, wchar_t *)=0;
 void MGL_EXPORT mgl_ask_gets(const wchar_t *quest, wchar_t *res)
@@ -73,9 +75,9 @@ MGL_EXPORT void (*mgl_progress_func)(int value, int maximal, HMGL)=mgl_progress_
 void MGL_EXPORT mgl_progress(int value, int maximal, HMGL gr)
 {	mgl_progress_func(value, maximal, gr);	}
 //-----------------------------------------------------------------------------
-mglFunc::mglFunc(long p, const wchar_t *f)
+mglFunc::mglFunc(long p, const wchar_t *f):func(f)
 {
-	pos = p;	func = f;
+	pos = p;
 	size_t i;
 	for(i=0;(isalnum(f[i]) || f[i]=='_');i++);
 	narg = wcstol(f+i+1,0,0);	func.crop(0,i);
@@ -182,10 +184,13 @@ int mglParser::Exec(mglGraph *gr, const wchar_t *com, long n, mglArg *a, const s
 						if(s[k]>' ')	alph=true;
 						if(alph && s[k]<=' ')	break;
 					}
-					HMDT d1 = mglFormulaCalc(s.substr(j+1,k-j),this, DataList);
-					HMDT d2 = mglFormulaCalc(s.substr(k+1),this, DataList);
-					mglprintf(buf,64,L" %g %g",d1->a[0],d2->a[0]);
-					s = o+buf;	delete d1;	delete d2;
+					if(k<s.length())
+					{
+						HMDT d1 = mglFormulaCalc(s.substr(j+1,k-j),this, DataList);
+						HMDT d2 = mglFormulaCalc(s.substr(k+1),this, DataList);
+						mglprintf(buf,64,L" %g %g",d1->a[0],d2->a[0]);
+						s = o+buf;	delete d1;	delete d2;
+					}
 				}
 				else if(o!=L"legend")	// 1 argument
 				{
@@ -424,7 +429,11 @@ void mglParser::FillArg(mglGraph *gr, int k, std::wstring *arg, mglArg *a)
 					id.push_back(4);	s.push_back(str.substr(ii,i-ii));
 					op=0;	ii=i+1;	ns--;
 				}
-				else if(na%2==0 && np==1 && str[i]==')' && ns==0)	np--;
+				else if(na%2==0 && np>0 && ns==0)
+				{
+					if(str[i]==')')	np--;
+					if(str[i]=='(')	np++;
+				}
 			}
 			if(op && ll>ii)
 			{	id.push_back(op);	s.push_back(str.substr(ii,ll-ii));	}
@@ -853,7 +862,7 @@ int mglParser::Parse(mglGraph *gr, std::wstring str, long pos)
 			if(n)	st.state = MGL_ST_BREAK;
 			stack.push_back(st);	delete []a;	return n;
 		}
-		// alocate new arrays and execute the command itself
+		// allocate new arrays and execute the command itself
 		n = PreExec(gr, k, &(arg[0]), a);
 		if(n>0)	n--;
 		else if(!arg[0].compare(L"setsize") && !AllowSetSize)	n = 2;
@@ -1090,7 +1099,7 @@ void mglParser::Execute(mglGraph *gr, const wchar_t *text)
 		if(text[i]=='\\')	next = i;
 		else if(text[i]>' ')next = 0;
 		if(text[i]=='\n')
-		{	// if string need to be continued then I but ' ' instead of 0x0 and
+		{	// if string need to be continued then I put ' ' instead of 0x0 and
 			// pointer next string to 0x0. Last one for keeping number of strings.
 			if(next)
 			{	for(size_t ii=next;ii<=i;ii++)	wcs[ii]='\b';	str[n] = wcs+s-1;	next=0;	}
