@@ -153,7 +153,7 @@ void MemPanel::refresh()
 		s = QString::fromWCharArray(v->Name());
 		it = new QTableWidgetItem(s);
 		tab->setItem(m,0,it);	it->setFlags(flags);
-		s.sprintf("%ld * %ld * %ld", v->GetNx(), v->GetNy(), v->GetNz());
+		s.asprintf("%ld * %ld * %ld", v->GetNx(), v->GetNy(), v->GetNz());
 		it = new QTableWidgetItem(s);
 		tab->setItem(m,1,it);	it->setFlags(flags);
 		it->setTextAlignment(Qt::AlignHCenter|Qt::AlignVCenter);
@@ -167,16 +167,16 @@ void MemPanel::refresh()
 		else if(dynamic_cast<mglDataT*>(v))	sv = sizeof(mglDataT);
 		if(sv==0)	s = _("unknown");
 #if MGL_SIZEOF_LONG>4
-//		else if((sv>>80L)>0)	s.sprintf("%ld Yb",sv>>80L);
-//		else if((sv>>70L)>0)	s.sprintf("%ld Zb",sv>>70L);
-		else if((sv>>60L)>0)	s.sprintf("%ld Eb",sv>>60L);
-		else if((sv>>50L)>0)	s.sprintf("%ld Pb",sv>>50L);
-		else if((sv>>40L)>0)	s.sprintf("%ld Tb",sv>>40L);
+//		else if((sv>>80L)>0)	s.asprintf("%ld Yb",sv>>80L);
+//		else if((sv>>70L)>0)	s.asprintf("%ld Zb",sv>>70L);
+		else if((sv>>60L)>0)	s.asprintf("%ld Eb",sv>>60L);
+		else if((sv>>50L)>0)	s.asprintf("%ld Pb",sv>>50L);
+		else if((sv>>40L)>0)	s.asprintf("%ld Tb",sv>>40L);
 #endif
-		else if((sv>>30L)>0)	s.sprintf("%ld Gb",sv>>30L);
-		else if((sv>>20L)>0)	s.sprintf("%ld Mb",sv>>20L);
-		else if((sv>>10L)>0)	s.sprintf("%ld Kb",sv>>10L);
-		else	s.sprintf("%ld b",sv);
+		else if((sv>>30L)>0)	s.asprintf("%ld Gb",sv>>30L);
+		else if((sv>>20L)>0)	s.asprintf("%ld Mb",sv>>20L);
+		else if((sv>>10L)>0)	s.asprintf("%ld Kb",sv>>10L);
+		else	s.asprintf("%ld b",sv);
 		it = new QTableWidgetItem(s);
 		tab->setItem(m,2,it);	it->setFlags(flags);
 		it->setTextAlignment(Qt::AlignRight|Qt::AlignVCenter);
