@@ -31,7 +31,7 @@ QMGLSyntax::QMGLSyntax(QTextEdit *textEdit) : QSyntaxHighlighter(textEdit)	{}
 //-----------------------------------------------------------------------------
 void QMGLSyntax::highlightBlock(const QString &text)
 {
-	register int i, j, m = text.length(),s=0;
+	int i, j, m = text.length(),s=0;
 	bool arg = false, nl = true;
 	QString num("+-.0123456789:");
 	i=0;
@@ -50,7 +50,8 @@ void QMGLSyntax::highlightBlock(const QString &text)
 	}
 	for(;i<m;i++)				// highlight paragraph
 	{
-		if(text[i]=='(')	s++;	if(text[i]==')')	s--;
+		if(text[i]=='(')	s++;
+		if(text[i]==')')	s--;
 		if(text[i]==' ' || text[i]=='\t')	continue;
 		else if(text[i]=='#')	// comment
 		{	setFormat(i,m-i,mglColorScheme[0]);	break;	}
@@ -100,9 +101,9 @@ void QMGLSyntax::highlightBlock(const QString &text)
 			setFormat(i,1,mglColorScheme[5]);
 		else		// number as its symbolic id
 		{
-			const char *o[]={"nan","inf","pi","on","off"};
-			int l[5] = {3, 3, 2, 2, 3};
-			for(j=0;j<5;j++)
+			const char *o[6]={"nan","inf","pi","on","off","all"};
+			int l[6] = {3, 3, 2, 2, 3, 3};
+			for(j=0;j<6;j++)
 				if(text.indexOf(o[j],i)==i && (i+l[j]==text.length() || text[i+l[j]].isSpace()))
 					setFormat(i,l[j],mglColorScheme[5]);
 		}
@@ -114,7 +115,7 @@ MessSyntax::MessSyntax(QTextEdit *textEdit) : QSyntaxHighlighter(textEdit)	{}
 //-----------------------------------------------------------------------------
 void MessSyntax::highlightBlock(const QString &text)
 {
-	if(text.left(7) == ("In line"))
+	if(text.contains("in line "))
 		setFormat(0, text.length(), QColor(255,0,0));
 }
 //-----------------------------------------------------------------------------
