@@ -58,7 +58,6 @@ uses\n\
 Windows, Graphics,\n\
 {$ENDIF}\n\
 Math;\n\n\
-const MGL_VER2 = 2.2;\n\
 //* This define enables double precision in MathGL */\n\
 MGL_USE_DOUBLE = 1;\n\n\
 const\n\
@@ -421,7 +420,7 @@ bool parse_file(const char *fname, FILE *out)
 		{
 			do
 			{
-				fgets(buf, 1024, fp);
+				if(!fgets(buf, 1024, fp))	break;
 			}
 			while ( !strstr(buf, "*/") );
 			continue;
