@@ -503,7 +503,7 @@ void QMathGL::mouseMoveEvent(QMouseEvent *ev)
 			if(gg)	emit perChanged(int(per));
 			refresh();
 		}
-		if(ev->buttons()&Qt::MidButton)	// shift
+		if(ev->buttons()&Qt::MiddleButton)	// shift
 		{
 			mreal ff = 1./sqrt(mreal(width()*height()));
 			mreal dx = (x0-xe)*ff*(x2-x1), dy = (y0-ye)*ff*(y2-y1);
@@ -513,7 +513,7 @@ void QMathGL::mouseMoveEvent(QMouseEvent *ev)
 		refresh();
 	}
 	else if(zoom)	refresh();
-	else if(ev->buttons()&Qt::MidButton)	// shift axis
+	else if(ev->buttons()&Qt::MiddleButton)	// shift axis
 	{
 		mreal ff = 1./sqrt(mreal(width()*height()));
 		mreal dx = (x0-xe)*ff*(ax2-ax1), dy = (y0-ye)*ff*(ay2-ay1);
@@ -665,14 +665,14 @@ void QMathGL::wheelEvent(QWheelEvent *ev)
 	if(!enableWheel)	{	ev->ignore();	return;	}
 	if(rotate)	// zoom
 	{
-		mreal d,c,f=exp(0.001*ev->delta())/2;
+		mreal d,c,f=exp(0.001*ev->angleDelta().y())/2;
 		d = (y2-y1)*f;	c = (y2+y1)/2;	y1 = c-d;	y2 = c+d;
 		d = (x2-x1)*f;	c = (x2+x1)/2;	x1 = c-d;	x2 = c+d;
 		refresh();	ev->accept();
 	}
 	else 		// zoom axis
 	{
-		mreal d,c,f=exp(0.001*ev->delta())/2;
+		mreal d,c,f=exp(0.001*ev->angleDelta().y())/2;
 		d = (ay2-ay1)*f;	c = (ay2+ay1)/2;	ay1 = c-d;	ay2 = c+d;
 		d = (ax2-ax1)*f;	c = (ax2+ax1)/2;	ax1 = c-d;	ax2 = c+d;
 		mgl_zoom_axis(gr,ax1,ay1,0,0,ax2,ay2,0,0);
@@ -873,7 +873,7 @@ void QMathGL::setSize(int w, int h)
 //-----------------------------------------------------------------------------
 void QMathGL::about()
 {
-	QString s = _("MathGL v. 2.") + QString::number(MGL_VER2) + _("\n(c) Alexey Balakin, 2007\nhttp://mathgl.sourceforge.net/");
+	QString s = _("MathGL v. 2.") + QString(MGL_VER_STRING) + _("\n(c) Alexey Balakin, 2007\nhttp://mathgl.sourceforge.net/");
 	QMessageBox::about(this, _("MathGL - about"), s);
 }
 //-----------------------------------------------------------------------------
@@ -882,7 +882,7 @@ void QMathGL::aboutQt()	{	QMessageBox::aboutQt(this, _("About Qt"));	}
 void QMathGL::print()
 {
 	QPrinter *printer = new QPrinter;
-	printer->setOrientation(getRatio()>1 ? QPrinter::Landscape : QPrinter::Portrait);
+	printer->setPageOrientation(getRatio()>1 ? QPageLayout::Landscape : QPageLayout::Portrait);
 	QPrintDialog printDlg(printer, this);
 	if (printDlg.exec() == QDialog::Accepted)
 	{
@@ -1018,7 +1018,7 @@ void mglCanvasQT::Window(int argc, char **argv, int (*draw)(mglBase *gr, void *p
 
 	if(!qApp)
 	{
-		QCoreApplication::setAttribute(Qt::AA_X11InitThreads);
+// 		QCoreApplication::setAttribute(Qt::AA_X11InitThreads);
 		if(!argv)	{	argc_ = 0;	argv_=&parg;	}
 		else		{	argc_ = argc;	argv_=argv;	}
 		QApplication *a = new QApplication(argc_, argv_);
